@@ -20,5 +20,5 @@
 ;; This will be T if this was a lisp-only build
 (defparameter *autoconf-lisp-only-build* (eq t 'nil))
  
-(defparameter *maxima-source-root* "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_math_maxima/maxima/work/maxima-5.47.0")
+(defparameter *maxima-source-root* "/opt/local/var/macports/build/maxima-0dc76224/work/maxima-5.47.0")
 (defparameter *maxima-default-layout-autotools* "true")
